summaryrefslogtreecommitdiff
path: root/vehicle.h
diff options
context:
space:
mode:
Diffstat (limited to 'vehicle.h')
-rw-r--r--vehicle.h20
1 files changed, 10 insertions, 10 deletions
diff --git a/vehicle.h b/vehicle.h
index 0c4cfcb3d..398105837 100644
--- a/vehicle.h
+++ b/vehicle.h
@@ -186,14 +186,14 @@ struct Depot {
uint16 town_index;
};
-// train checkpoint
-struct Checkpoint {
+// train waypoint
+struct Waypoint {
TileIndex xy;
uint16 town_or_string; // if this is 0xC000, it's a string id, otherwise a town.
ViewportSign sign;
uint16 build_date;
byte stat_id;
- byte deleted; // this is a delete counter. when it reaches 0, the checkpoint struct is deleted.
+ byte deleted; // this is a delete counter. when it reaches 0, the waypoint struct is deleted.
};
enum {
@@ -213,7 +213,7 @@ enum {
OT_LOADING = 3,
OT_LEAVESTATION = 4,
OT_DUMMY = 5,
- OT_GOTO_CHECKPOINT = 6,
+ OT_GOTO_WAYPOINT = 6,
OT_MASK = 0x1F,
};
@@ -290,9 +290,9 @@ void DeleteVehicleSchedule(Vehicle *v);
Vehicle *IsScheduleShared(Vehicle *v);
Depot *AllocateDepot();
-Checkpoint *AllocateCheckpoint();
-void UpdateCheckpointSign(Checkpoint *cp);
-void RedrawCheckpointSign(Checkpoint *cp);
+Waypoint *AllocateWaypoint();
+void UpdateWaypointSign(Waypoint *cp);
+void RedrawWaypointSign(Waypoint *cp);
void InitializeTrains();
bool IsTrainDepotTile(TileIndex tile);
@@ -346,7 +346,7 @@ uint GetFreeUnitNumber(byte type);
int LoadUnloadVehicle(Vehicle *v);
int GetDepotByTile(uint tile);
-uint GetCheckpointByTile(uint tile);
+uint GetWaypointByTile(uint tile);
void DoDeleteDepot(uint tile);
@@ -388,8 +388,8 @@ VARDEF uint16 *_ptr_to_next_order;
VARDEF Depot _depots[255];
-// 128 checkpoints
-VARDEF Checkpoint _checkpoints[128];
+// 128 waypoints
+VARDEF Waypoint _waypoints[128];
// NOSAVE: Can be regenerated by inspecting the vehicles.
VARDEF VehicleID _vehicle_position_hash[0x1000];